Package: acnr
Type: Package
Title: Annotated Copy-Number Regions
Version: 1.0.0
Date: 2017-04-15
Authors@R: c(person("Morgane", "Pierre-Jean", role = c("aut", "cre"),
                     email = "morgane.pierrejean@genopole.cnrs.fr"),
              person("Pierre", "Neuvial", role = "aut"))
Description: Provides SNP array data from different types of
    copy-number regions. These regions were identified manually by the authors
    of the package and may be used to generate realistic data sets with known
    truth.
License: LGPL (>= 2.1)
Depends: R (>= 2.10),
Suggests: R.utils, knitr, rmarkdown, testthat
RoxygenNote: 5.0.1
VignetteBuilder: knitr
URL: https://github.com/mpierrejean/acnr
BugReports: https://github.com/mpierrejean/acnr/issues
NeedsCompilation: no
Packaged: 2017-04-18 08:34:55 UTC; mpierre-jean
Author: Morgane Pierre-Jean [aut, cre],
  Pierre Neuvial [aut]
Maintainer: Morgane Pierre-Jean <morgane.pierrejean@genopole.cnrs.fr>
Repository: CRAN
Date/Publication: 2017-04-18 09:58:15 UTC
Built: R 4.6.0; ; 2026-04-26 09:27:53 UTC; unix
